@@ -53,6 +53,14 @@ DISCOVER_BACKEND_PLUGIN(FlatpakBackend)
 class FlatpakSource
 {
 public:
+    FlatpakSource(FlatpakBackend *backend, FlatpakInstallation *installation)
+        : m_remote(nullptr)
+        , m_installation(installation)
+        , m_backend(backend)
+    {
+        g_object_ref(m_installation);
+    }
+
     FlatpakSource(FlatpakBackend *backend, FlatpakInstallation *installation, FlatpakRemote *remote)
         : m_remote(remote)
         , m_installation(installation)
@@ -65,19 +73,27 @@ public:
 
     ~FlatpakSource()
     {
-        g_object_unref(m_remote);
+        if (m_remote) {
+            g_object_unref(m_remote);
+        }
         g_object_unref(m_installation);
     }
 
+    QString url() const
+    {
+        return m_remote ? flatpak_remote_get_url(m_remote) : QString();
+    }
+
     bool isEnabled() const
     {
-        return !flatpak_remote_get_disabled(m_remote);
+        return m_remote && !flatpak_remote_get_disabled(m_remote);
     }
 
     QString appstreamIconsDir() const {
         return m_appstreamIconsDir;
     }
     QString appstreamDir() const {
+        Q_ASSERT(m_remote);
         g_autoptr(GFile) appstreamDir = flatpak_remote_get_appstream_dir(m_remote, nullptr);
         if (!appstreamDir) {
             qWarning() << "No appstream dir for" << flatpak_remote_get_name(m_remote);
@@ -89,7 +105,7 @@ public:
 
     QString name() const
     {
-        return QString::fromUtf8(flatpak_remote_get_name(m_remote));
+        return m_remote ? QString::fromUtf8(flatpak_remote_get_name(m_remote)) : QString();
     }
 
     FlatpakInstallation *installation() const
@@ -309,8 +325,9 @@ FlatpakRemote *FlatpakBackend::getFlatpakRemoteByUrl(const QString &url, Flatpak
     return nullptr;
 }
 
-FlatpakInstalledRef *FlatpakBackend::getInstalledRefForApp(FlatpakResource *resource) const
+FlatpakInstalledRef *FlatpakBackend::getInstalledRefForApp(const FlatpakResource *resource) const
 {
+    Q_ASSERT(resource->resourceType() != FlatpakResource::Source);
     g_autoptr(GError) localError = nullptr;
 
     const auto type = resource->resourceType() == FlatpakResource::DesktopApp ? FLATPAK_REF_KIND_APP : FLATPAK_REF_KIND_RUNTIME;
@@ -557,7 +574,7 @@ void FlatpakBackend::addAppFromFlatpakBundle(const QUrl &url, ResultsStream *str
     resource->setType(FlatpakResource::DesktopApp);
 
     if (!m_localSource) {
-        m_localSource.reset(new FlatpakSource(this, preferredInstallation(), nullptr));
+        m_localSource.reset(new FlatpakSource(this, preferredInstallation()));
         m_flatpakSources += m_localSource;
     }
     m_localSource->addResource(resource);
@@ -566,23 +583,43 @@ void FlatpakBackend::addAppFromFlatpakBundle(const QUrl &url, ResultsStream *str
 
 void FlatpakBackend::addAppFromFlatpakRef(const QUrl &url, ResultsStream *stream)
 {
+    Q_ASSERT(url.isLocalFile());
     QSettings settings(url.toLocalFile(), QSettings::NativeFormat);
     const QString refurl = settings.value(QStringLiteral("Flatpak Ref/Url")).toString();
     const QString name = settings.value(QStringLiteral("Flatpak Ref/Name")).toString();
+    const QString remoteName = settings.value(QStringLiteral("Flatpak Ref/SuggestRemoteName")).toString();
+    g_autoptr(GError) error = nullptr;
 
-    auto item = m_sources->sourceByUrl(refurl);
-    if (item) {
-        const auto resources = resourcesByAppstreamName(name);
-        for (auto resource : resources) {
-            if (resource->origin() == item->data(AbstractSourcesBackend::IdRole)) {
-                stream->resourcesFound({resource});
+    // If we already added the remote, just go with it
+    g_autoptr(FlatpakRemote) remote = flatpak_installation_get_remote_by_name(preferredInstallation(), remoteName.toUtf8().constData(), m_cancellable, &error);
+    if (remote && flatpak_remote_get_url(remote) != refurl) {
+        remote = nullptr;
+    }
+    if (remote) {
+        m_refreshAppstreamMetadataJobs++;
+        auto source = integrateRemote(preferredInstallation(), remote);
+        if (source) {
+            auto searchComponent = [this, stream, source, name] {
+                auto comps = source->m_pool->componentsById(name);
+                if (comps.isEmpty()) {
+                    const QString nameWithDesktop = name + QLatin1String(".desktop");
+                    comps = source->m_pool->componentsById(nameWithDesktop);
+                }
+                auto resources = kTransform<QVector<AbstractResource *>>(comps, [this, source](const auto &comp) {
+                    return resourceForComponent(comp, source);
+                });
+                stream->resourcesFound(resources);
                 stream->finish();
-                return;
+            };
+            if (source->m_pool) {
+                QTimer::singleShot(0, this, searchComponent);
+            } else {
+                connect(this, &FlatpakBackend::initialized, stream, searchComponent);
             }
+            return;
         }
     }
 
-    g_autoptr(GError) error = nullptr;
     g_autoptr(FlatpakRemoteRef) remoteRef = nullptr;
     {
         QFile f(url.toLocalFile());
@@ -607,8 +644,6 @@ void FlatpakBackend::addAppFromFlatpakRef(const QUrl &url, ResultsStream *stream
         }
     }
 
-    const auto remoteName = flatpak_remote_ref_get_remote_name(remoteRef);
-
     auto ref = FLATPAK_REF(remoteRef);
 
     AppStream::Component asComponent;
@@ -633,11 +668,11 @@ void FlatpakBackend::addAppFromFlatpakRef(const QUrl &url, ResultsStream *stream
 
     auto resource = new FlatpakResource(asComponent, preferredInstallation(), this);
     resource->setFlatpakFileType(FlatpakResource::FileFlatpakRef);
-    resource->setOrigin(QString::fromUtf8(remoteName));
+    resource->setOrigin(remoteName);
     resource->updateFromRef(ref);
 
     QUrl runtimeUrl = QUrl(settings.value(QStringLiteral("Flatpak Ref/RuntimeRepo")).toString());
-    auto refSource = QSharedPointer<FlatpakSource>::create(this, preferredInstallation(), nullptr);
+    auto refSource = QSharedPointer<FlatpakSource>::create(this, preferredInstallation());
     m_flatpakSources += refSource;
     if (!runtimeUrl.isEmpty()) {
         // We need to fetch metadata to find information about required runtime
@@ -728,7 +763,8 @@ void FlatpakBackend::addSourceFromFlatpakRepo(const QUrl &url, ResultsStream *st
     resource->setFlatpakName(url.fileName().remove(QStringLiteral(".flatpakrepo")));
     resource->setType(FlatpakResource::Source);
 
-    auto repo = flatpak_installation_get_remote_by_name(preferredInstallation(), resource->flatpakName().toUtf8().constData(), m_cancellable, nullptr);
+    g_autoptr(FlatpakRemote) repo =
+        flatpak_installation_get_remote_by_name(preferredInstallation(), resource->flatpakName().toUtf8().constData(), m_cancellable, nullptr);
     if (!repo) {
         resource->setState(AbstractResource::State::None);
     } else {
@@ -786,28 +822,43 @@ void FlatpakBackend::metadataRefreshed()
     }
 }
 
-void FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, FlatpakRemote *remote)
+QSharedPointer<FlatpakSource> FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, FlatpakRemote *remote)
 {
     Q_ASSERT(m_refreshAppstreamMetadataJobs != 0);
+    for (auto source : qAsConst(m_flatpakSources)) {
+        if (source->url() == flatpak_remote_get_url(remote)) {
+            qDebug() << "do not add a source twice" << source << remote;
+            metadataRefreshed();
+            return source;
+        }
+    }
+    for (auto source : qAsConst(m_flatpakLoadingSources)) {
+        if (source->url() == flatpak_remote_get_url(remote)) {
+            qDebug() << "do not add a source twice" << source << remote;
+            metadataRefreshed();
+            return source;
+        }
+    }
 
-    QSharedPointer<FlatpakSource> source(new FlatpakSource(this, flatpakInstallation, remote));
+    auto source = QSharedPointer<FlatpakSource>::create(this, flatpakInstallation, remote);
     if (!source->isEnabled() || flatpak_remote_get_noenumerate(remote)) {
         metadataRefreshed();
-        return;
+        return {};
     }
 
     const QString appstreamDirPath = source->appstreamDir();
     if (!QFile::exists(appstreamDirPath)) {
         qWarning() << "No" << appstreamDirPath << "appstream metadata found for" << source->name();
         metadataRefreshed();
-        return;
+        return {};
     }
 
     AppStream::Pool *pool = new AppStream::Pool(this);
-    source->m_pool = pool;
     auto fw = new QFutureWatcher<bool>(this);
     const auto sourceName = source->name();
     connect(fw, &QFutureWatcher<bool>::finished, this, [this, fw, pool, source]() {
+        source->m_pool = pool;
+        m_flatpakLoadingSources.removeAll(source);
         if (fw->result()) {
             m_flatpakSources += source;
         } else {
@@ -827,6 +878,8 @@ void FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, F
     pool->setCacheLocation(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + "/flatpak-appstream/" + subdir);
     QDir().mkpath(pool->cacheLocation());
     fw->setFuture(QtConcurrent::run(&m_threadPool, pool, &AppStream::Pool::load));
+    m_flatpakLoadingSources << source;
+    return source;
 }
 
 void FlatpakBackend::loadLocalUpdates(FlatpakInstallation *flatpakInstallation)
@@ -1105,7 +1158,7 @@ bool FlatpakBackend::updateAppSizeFromRemote(FlatpakResource *resource)
             return false;
         }
         resource->setInstalledSize(flatpak_installed_ref_get_installed_size(ref));
-    } else {
+    } else if (resource->resourceType() != FlatpakResource::Source) {
         if (resource->origin().isEmpty()) {
             qWarning() << "Failed to get size of" << resource->name() << " because of missing origin";
             return false;
@@ -1340,10 +1393,12 @@ QVector<AbstractResource *> FlatpakBackend::resourcesByAppstreamName(const QStri
     QVector<AbstractResource *> resources;
     const QString nameWithDesktop = name + QLatin1String(".desktop");
     for (const auto &source : m_flatpakSources) {
-        auto comps = source->m_pool->componentsById(name) + source->m_pool->componentsById(nameWithDesktop);
-        resources << kTransform<QVector<AbstractResource *>>(comps, [this, source](const auto &comp) {
-            return resourceForComponent(comp, source);
-        });
+        if (source->m_pool) {
+            const auto comps = source->m_pool->componentsById(name) + source->m_pool->componentsById(nameWithDesktop);
+            resources << kTransform<QVector<AbstractResource *>>(comps, [this, source](const auto &comp) {
+                return resourceForComponent(comp, source);
+            });
+        }
     }
     auto f = [this](AbstractResource *l, AbstractResource *r) {
         return flatpakResourceLessThan(l, r);
@@ -1419,7 +1474,8 @@ Transaction *FlatpakBackend::installApplication(AbstractResource *app, const Add
             m_refreshAppstreamMetadataJobs++;
             // Make sure we update appstream metadata first
             // FIXME we have to let flatpak to return the remote as the one created by FlatpakSourcesBackend will not have appstream directory
-            auto repo = flatpak_installation_get_remote_by_name(resource->installation(), flatpak_remote_get_name(remote), m_cancellable, nullptr);
+            g_autoptr(FlatpakRemote) repo =
+                flatpak_installation_get_remote_by_name(resource->installation(), flatpak_remote_get_name(remote), m_cancellable, nullptr);
             refreshAppstreamMetadata(resource->installation(), repo);
         }
         return nullptr;
