@@ -34,6 +34,10 @@ public:
 
     QString errorMessage() const;
     bool result() const;
+    bool cancelled() const
+    {
+        return m_cancelled;
+    }
 
     void addErrorMessage(const QString &error);
 
@@ -46,6 +50,7 @@ private:
     FlatpakTransaction *m_transaction;
 
     bool m_result = false;
+    bool m_cancelled = false;
     int m_progress = 0;
     quint64 m_speed = 0;
     QString m_errorMessage;
