@@ -8,16 +8,16 @@
 #ifndef RESOURCESPROXYMODEL_H
 #define RESOURCESPROXYMODEL_H
 
+#include <QQmlParserStatus>
 #include <QSortFilterProxyModel>
 #include <QString>
 #include <QStringList>
-#include <QQmlParserStatus>
 
 #include <Category/Category.h>
 
-#include "discovercommon_export.h"
 #include "AbstractResource.h"
 #include "AbstractResourcesBackend.h"
+#include "discovercommon_export.h"
 
 class AggregatedResultsStream;
 
@@ -27,7 +27,7 @@ class DISCOVERCOMMON_EXPORT ResourcesProxyModel : public QAbstractListModel, pub
     Q_INTERFACES(QQmlParserStatus)
     Q_PROPERTY(Roles sortRole READ sortRole WRITE setSortRole NOTIFY sortRoleChanged)
     Q_PROPERTY(Qt::SortOrder sortOrder READ sortOrder WRITE setSortOrder NOTIFY sortOrderChanged)
-    Q_PROPERTY(Category* filteredCategory READ filteredCategory WRITE setFiltersFromCategory NOTIFY categoryChanged)
+    Q_PROPERTY(Category *filteredCategory READ filteredCategory WRITE setFiltersFromCategory NOTIFY categoryChanged)
     Q_PROPERTY(QString originFilter READ originFilter WRITE setOriginFilter)
     Q_PROPERTY(AbstractResource::State stateFilter READ stateFilter WRITE setStateFilter NOTIFY stateFilterChanged)
     Q_PROPERTY(bool filterMinimumState READ filterMinimumState WRITE setFilterMinimumState NOTIFY filterMinimumStateChanged)
@@ -41,7 +41,7 @@ class DISCOVERCOMMON_EXPORT ResourcesProxyModel : public QAbstractListModel, pub
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
     Q_PROPERTY(bool sortByRelevancy READ sortByRelevancy NOTIFY sortByRelevancyChanged)
 public:
-    explicit ResourcesProxyModel(QObject* parent = nullptr);
+    explicit ResourcesProxyModel(QObject *parent = nullptr);
     enum Roles {
         NameRole = Qt::UserRole,
         IconRole,
@@ -64,7 +64,7 @@ public:
         SizeRole,
         LongDescriptionRole,
         SourceIconRole,
-        ReleaseDateRole
+        ReleaseDateRole,
     };
     Q_ENUM(Roles)
 
@@ -78,60 +78,72 @@ public:
     void setStateFilter(AbstractResource::State s);
     AbstractResource::State stateFilter() const;
     void setSortRole(Roles sortRole);
-    Roles sortRole() const { return m_sortRole; }
+    Roles sortRole() const
+    {
+        return m_sortRole;
+    }
     void setSortOrder(Qt::SortOrder sortOrder);
-    Qt::SortOrder sortOrder() const { return m_sortOrder; }
+    Qt::SortOrder sortOrder() const
+    {
+        return m_sortOrder;
+    }
     void setFilterMinimumState(bool filterMinimumState);
     bool filterMinimumState() const;
 
-    Category* filteredCategory() const;
-    
+    Category *filteredCategory() const;
+
     QString mimeTypeFilter() const;
-    void setMimeTypeFilter(const QString& mime);
+    void setMimeTypeFilter(const QString &mime);
 
     QString extends() const;
     void setExtends(const QString &extends);
 
     QUrl resourcesUrl() const;
-    void setResourcesUrl(const QUrl& resourcesUrl);
+    void setResourcesUrl(const QUrl &resourcesUrl);
 
     bool allBackends() const;
     void setAllBackends(bool allBackends);
 
     QVariantList subcategories() const;
 
-    QVariant data(const QModelIndex & index, int role) const override;
-    int rowCount(const QModelIndex & parent = {}) const override;
+    QVariant data(const QModelIndex &index, int role) const override;
+    int rowCount(const QModelIndex &parent = {}) const override;
 
-    Q_SCRIPTABLE int indexOf(AbstractResource* res);
-    Q_SCRIPTABLE AbstractResource* resourceAt(int row) const;
+    Q_SCRIPTABLE int indexOf(AbstractResource *res);
+    Q_SCRIPTABLE AbstractResource *resourceAt(int row) const;
 
-    bool isBusy() const { return m_currentStream != nullptr; }
+    bool isBusy() const
+    {
+        return m_currentStream != nullptr;
+    }
 
-    bool lessThan(AbstractResource* rl, AbstractResource* rr) const;
+    bool lessThan(AbstractResource *rl, AbstractResource *rr) const;
     Q_SCRIPTABLE void invalidateFilter();
     void invalidateSorting();
 
-    bool canFetchMore(const QModelIndex & parent) const override;
-    void fetchMore(const QModelIndex & parent) override;
+    bool canFetchMore(const QModelIndex &parent) const override;
+    void fetchMore(const QModelIndex &parent) override;
     bool sortByRelevancy() const;
 
-    void classBegin() override {}
+    void classBegin() override
+    {
+    }
     void componentComplete() override;
 
 private Q_SLOTS:
-    void refreshBackend(AbstractResourcesBackend* backend, const QVector<QByteArray>& properties);
-    void refreshResource(AbstractResource* resource, const QVector<QByteArray>& properties);
-    void removeResource(AbstractResource* resource);
-private:
-    void sortedInsertion(const QVector<AbstractResource*> &res);
-    QVariant roleToValue(AbstractResource* res, int role) const;
+    void refreshBackend(AbstractResourcesBackend *backend, const QVector<QByteArray> &properties);
+    void refreshResource(AbstractResource *resource, const QVector<QByteArray> &properties);
+    void removeResource(AbstractResource *resource);
 
-    QVector<int> propertiesToRoles(const QVector<QByteArray>& properties) const;
-    void addResources(const QVector<AbstractResource*> &res);
+private:
+    void sortedInsertion(const QVector<AbstractResource *> &res);
+    QVariant roleToValue(AbstractResource *res, int role) const;
+
+    QVector<int> propertiesToRoles(const QVector<QByteArray> &properties) const;
+    void addResources(const QVector<AbstractResource *> &res);
     void fetchSubcategories();
-    void removeDuplicates(QVector<AbstractResource *>& newResources);
-    bool isSorted(const QVector<AbstractResource*> & resources);
+    void removeDuplicates(QVector<AbstractResource *> &newResources);
+    bool isSorted(const QVector<AbstractResource *> &resources);
 
     Roles m_sortRole;
     Qt::SortOrder m_sortOrder;
@@ -142,9 +154,9 @@ private:
     AbstractResourcesBackend::Filters m_filters;
     QVariantList m_subcategories;
 
-    QVector<AbstractResource*> m_displayedResources;
+    QVector<AbstractResource *> m_displayedResources;
     const QHash<int, QByteArray> m_roles;
-    AggregatedResultsStream* m_currentStream;
+    AggregatedResultsStream *m_currentStream;
 
 Q_SIGNALS:
     void busyChanged(bool isBusy);
